#!/bin/bash 

# this script copies assests from the submodule of LAPIS_ASSETS into the Resources/cpk folder
# this script does not 'pull' the submodule from git and always copies from the version that is currently available, 
# the user has to ensure that LAPIS_ASSETS is at the correct version before running the script

# parameters, this script takes in the
# 1) platform type : android or ios

#Constants
ARG_ANDROID='ANDROID'
ARG_IOS='IOS'

#Constants
PATH_RELATIVE_LAPIS_ASSETS="../../"
FOLDER_NAME_LAPIS_ASSETS="lapis_assets/"
FOLDER_NAME_ANDROID="android/"
FOLDER_NAME_IOS="ios/"
FOLDER_NAME_ASSETS="assets/"
FOLDER_NAME_CPK="cpk/"

if [ "$#" -ne 1 ]; then
    echo "You must enter exactly 1 command line arguments"
    echo "eg1 copy_bundled_assets.sh $ARG_IOS"
	echo "eg2 copy_bundled_assets.sh $ARG_ANDROID"
	exit 1
fi

#transforming the arguments into an array
args=("$@")

#array of files
declare -a srcFileNames=("common_lang/sd/area/area1_common_tutorial.cpk" \
						 "common_lang/sd/battlebg/battleBg1_common_tutorial.cpk" \
						 "common_lang/sd/battleEffect/battleEffect1_common_tutorial.cpk" \
						 "common_lang/sd/beast/beast1_common_tutorial.cpk" \
						 "common_lang/sd/common/map_common_tutorial.cpk" \
						 "common_lang/sd/gacha/gachaeffect1_common_tutorial.cpk" \
						 "common_lang/sd/item/item1_common_tutorial.cpk" \
						 "common_lang/sd/mapEffect/mapEffect1_common_tutorial.cpk" \
						 "common_lang/sd/monster/monster1_common_tutorial.cpk" \
						 "common_lang/sd/monster/monster2_common_tutorial.cpk" \
						 "common_lang/sd/movie/movie1_common_pretutorial.cpk" \
						 "common_lang/sd/npc/npc1_common_tutorial.cpk" \
						 "common_lang/sd/npc/npc1_common_tutorial.cpk" \
						 "common_lang/sd/resources/resources_common_pretutorial.cpk" \
						 "common_lang/sd/resources/resources_common_tutorial.cpk" \
						 "common_lang/sd/skill/skill1_common_tutorial.cpk" \
						 "common_lang/sd/town/town1_common_tutorial.cpk" \
						 "common_lang/sd/tuto/tuto_common_tutorial.cpk" \
						 "common_lang/sd/uieffect/uieffect1_common_tutorial.cpk" \
						 "common_lang/sd/unit/unit1_common_tutorial.cpk" \
						 "common_lang/sd/unit/unit2_common_tutorial.cpk" \
						 "en/sd/item/item1_tutorial.cpk" \
						 "en/sd/gacha/gachaeffect1_tutorial.cpk" \
						 "en/sd/resources/resources_pretutorial.cpk" \
						 #"de/sd/resources/resources_pretutorial.cpk" \
						 #"fr/sd/resources/resources_pretutorial.cpk" \
						 #"es/sd/resources/resources_pretutorial.cpk" \
						 #"zh/sd/resources/resources_pretutorial.cpk" \
						 #"ko/sd/resources/resources_pretutorial.cpk" \
						 #"en/sd/resources/resources_tutorial.cpk" \
						 "en/sd/tuto/tuto_tutorial.cpk" \
						 "common_lang/sd/resources/resources_common_pretutorial.h" \
						 "common_lang/sd/resources/resources_common_tutorial.h" \
						 "common_lang/sd/resources/resources_common.h" \
						 "en/sd/resources/resources_pretutorial.h" \
						 "en/sd/resources/resources_tutorial.h" \
						 "en/sd/resources/resources.h" \
						 "Localized_Texts/text_Text_En.csv")
						
declare -a srcFileNamesiOS=("common_lang/sound/bgm/ios/la001_prelude_medQ.acb" \
						    "common_lang/sound/bgm/ios/la002_maintheme_medQ.acb" \
						    "common_lang/sound/bgm/ios/la005_battle1_medQ.acb" \
						    "common_lang/sound/bgm/ios/la102_event_gathering_medQ.acb" \
						    "common_lang/sound/bgm/ios/la006_battle_normalboss_medQ.acb" \
						    "common_lang/sound/bgm/ios/la009_battleend_medQ.acb" \
						    "common_lang/sound/bgm/ios/la004_map_world1_medQ.acb" \
						    "common_lang/sound/se/ios/SE_tutorial_medQ.acb" \
						    "common_lang/sound/se/ios/System_tutorial_medQ.acb")
						
declare -a srcFileNamesAndroid=("common_lang/sound/bgm/android/la001_prelude_medQ.acb" \
						        "common_lang/sound/bgm/android/la002_maintheme_medQ.acb" \
						        "common_lang/sound/bgm/android/la005_battle1_medQ.acb" \
						        "common_lang/sound/bgm/android/la102_event_gathering_medQ.acb" \
						        "common_lang/sound/bgm/android/la006_battle_normalboss_medQ.acb" \
						        "common_lang/sound/bgm/android/la009_battleend_medQ.acb" \
						        "common_lang/sound/bgm/android/la004_map_world1_medQ.acb" \
						        "common_lang/sound/se/android/SE_tutorial_medQ.acb" \
						        "common_lang/sound/se/android/System_tutorial_medQ.acb")
                      
declare -a dstFileNames=("cpk/common_lang/sd/area/area1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/battlebg/battleBg1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/battleEffect/battleEffect1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/beast/beast1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/common/map_common_tutorial.cpk" \
						 "cpk/common_lang/sd/gacha/gachaeffect1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/item/item1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/mapEffect/mapEffect1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/monster/monster1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/monster/monster2_common_tutorial.cpk" \
						 "cpk/common_lang/sd/movie/movie1_common_pretutorial.cpk" \
						 "cpk/common_lang/sd/npc/npc1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/npc/npc1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/resources/resources_common_pretutorial.cpk" \
						 "cpk/common_lang/sd/resources/resources_common_tutorial.cpk" \
						 "cpk/common_lang/sd/skill/skill1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/town/town1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/tuto/tuto_common_tutorial.cpk" \
						 "cpk/common_lang/sd/uieffect/uieffect1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/unit/unit1_common_tutorial.cpk" \
						 "cpk/common_lang/sd/unit/unit2_common_tutorial.cpk" \
						 "cpk/en/sd/item/item1_tutorial.cpk" \
						 "cpk/en/sd/gacha/gachaeffect1_tutorial.cpk" \
						 "cpk/en/sd/resources/resources_pretutorial.cpk" \
						 #"cpk/de/sd/resources/resources_pretutorial.cpk" \
						 #"cpk/fr/sd/resources/resources_pretutorial.cpk" \
						 #"cpk/es/sd/resources/resources_pretutorial.cpk" \
						 #"cpk/zh/sd/resources/resources_pretutorial.cpk" \
						 #"cpk/ko/sd/resources/resources_pretutorial.cpk" \
						 #"cpk/en/sd/resources/resources_tutorial.cpk" \
						 "cpk/en/sd/tuto/tuto_tutorial.cpk" \
						 "../Classes/crifs/resources_common_pretutorial.h" \
						 "../Classes/crifs/resources_common_tutorial.h" \
						 "../Classes/crifs/resources_common.h" \
						 "../Classes/crifs/resources_pretutorial.h" \
						 "../Classes/crifs/resources_tutorial.h" \
						 "../Classes/crifs/resources.h" \
						 "0ThfQQWd.csv")
						 
declare -a dstFileNamesiOS=("sound/bgm/la001_prelude.acb" \
						    "sound/bgm/la002_maintheme.acb" \
						    "sound/bgm/la005_battle1.acb" \
						    "sound/bgm/la102_event_gathering.acb" \
						    "sound/bgm/la006_battle_normalboss.acb" \
						    "sound/bgm/la009_battleend.acb" \
						    "sound/bgm/la004_map_world1.acb" \
						    "sound/se/SE_tutorial.acb" \
						    "sound/se/System_tutorial.acb")
						
declare -a dstFileNamesAndroid=("../proj.android/sound/bgm/la001_prelude.acb" \
						    	"../proj.android/sound/bgm/la002_maintheme.acb" \
						    	"../proj.android/sound/bgm/la005_battle1.acb" \
						    	"../proj.android/sound/bgm/la102_event_gathering.acb" \
						    	"../proj.android/sound/bgm/la006_battle_normalboss.acb" \
						    	"../proj.android/sound/bgm/la009_battleend.acb" \
						    	"../proj.android/sound/bgm/la004_map_world1.acb" \
						    	"../proj.android/sound/se/SE_tutorial.acb" \
						    	"../proj.android/sound/se/System_tutorial.acb")

#variables
DEVICE_TYPE="" #for use with the first parameter args[0]
SRC_ARRAY="" #for use with the src array of filenames
DST_ARRAY="" #for use with the dst array of filenames
                      	 	
HOME_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"$"/"

#checks the first parameter
if [ "${args[0]}" = "$ARG_ANDROID" ]; then
 	DEVICE_TYPE=$FOLDER_NAME_ANDROID
	SRC_ARRAY=( "${srcFileNames[@]}" )
 	SRC_ARRAY+=( "${srcFileNamesAndroid[@]}" )
 	DST_ARRAY=( "${dstFileNames[@]}" )
 	DST_ARRAY+=( "${dstFileNamesAndroid[@]}" )
elif [ "${args[0]}" = "$ARG_IOS" ]; then
 	DEVICE_TYPE=$FOLDER_NAME_IOS
	SRC_ARRAY=( "${srcFileNames[@]}" )
 	SRC_ARRAY+=( "${srcFileNamesiOS[@]}" )
	DST_ARRAY=( "${dstFileNames[@]}" )
 	DST_ARRAY+=( "${dstFileNamesiOS[@]}" )
else
	echo "The first parameter '${args[0]}' should only be '$ARG_ANDROID' or '$ARG_IOS'"
	exit 7
fi

#checks that the length of srcFileNames is equal to dstFileNamesiOS
if [ ${#SRC_ARRAY[@]} -ne ${#DST_ARRAY[@]} ]; then
	echo "src and dst arrays are not equal"
	exit 9
fi

#git clean to remove non tracked resources
echo git clean -f -d -X $HOME_DIR
git clean -f -d -X $HOME_DIR

#starts the copy
index=0
for i in "${SRC_ARRAY[@]}"
do
	#echo ${srcFileNames[index]}
	#echo $i
	#echo $index
# 	echo "src filename $index"
 	src=$HOME_DIR$PATH_RELATIVE_LAPIS_ASSETS$FOLDER_NAME_LAPIS_ASSETS$FOLDER_NAME_ASSETS${SRC_ARRAY[index]}
# 	echo $src

	MD5_DST=""
	MD5_SRC=""
	
	#checking for missing file in source folder
	if [ ! -f $src ]; then
		echo "ERROR Missing File in Lapis Assets $src" 
		exit 10
	else
		MD5_SRC=$(md5 -q $src)
	fi
	
# 	echo "dst filename $index"
 	dst=$HOME_DIR${DST_ARRAY[index]}
	
	#checking for file in dst folder and generating its MD5
	if [ -f $dst ]; then
		MD5_DST=$(md5 -q $dst)
	fi

	toCopy=false
	if [ "${MD5_DST}" = "" ]; then
		echo "Destination file doesn't exist. COPYING"
		toCopy=true
	elif [ "${MD5_DST}" != "${MD5_SRC}" ]; then
		echo "Destination file exists, but is different. OVERWRITING"
		toCopy=true
	elif [ "${MD5_DST}" = "${MD5_SRC}" ]; then
		echo "SAME Destination file exists."
	fi
	
	if  [ "${toCopy}" = true ]; then
		echo "cp $src $dst"
		#creating folder if it doesn't exist
		DIR=$(dirname "${dst}")
		mkdir -p "$DIR" && cp "$src" "$dst"
	else
		echo "Not overriding $dst"
	fi
	
	((++index))
done
